@@ -23,8 +23,6 @@ import os
 import stat
 import os.path as osp
 import logging
-import time
-import tempfile
 from string import Template
 from distutils.core import run_setup
 #from pkg_resources import FileMetadata
@@ -34,7 +32,6 @@ from subprocess import check_call, CalledProcessError
 from logilab.common import clcommands
 from logilab.common.logging_ext import ColorFormatter
 from logilab.common.shellutils import cp
-from logilab.common.fileutils import export
 from logilab.common.decorators import cached
 
 from logilab.devtools.lib.pkginfo import PackageInfo
@@ -42,29 +39,29 @@ from logilab.devtools.lgp import LOG_FORMAT, utils
 from logilab.devtools.lgp.exceptions import LGPException, LGPCommandException
 
 COMMANDS = {
-        "sdist" : {
-            "file": '$setup dist-gzip -e DIST_DIR=$dist_dir',
-            "Distribution": 'python setup.py -q sdist -d $dist_dir',
-            "PackageInfo": 'python setup.py -q sdist -d $dist_dir',
-            "debian": "uscan --noconf --download-current-version --destdir $dist_dir",
+        'file': {
+            "sdist": '$setup dist-gzip -e DIST_DIR=$dist_dir',
+            "clean": '$setup clean',
+            "version": '$setup version',
+            "project": '$setup project',
         },
-        "clean" : {
-            "file": '$setup clean',
-            "Distribution": 'python setup.py clean --all',
-            "PackageInfo": 'python setup.py clean --all',
-            "debian": "fakeroot debian/rules clean",
+        'Distribution': {
+            "sdist": 'python setup.py -q sdist -d $dist_dir',
+            "clean": 'python setup.py clean --all',
+            "version": 'python setup.py --version',
+            "project": 'python setup.py --name',
         },
-        "version" : {
-            "file": '$setup version',
-            "Distribution": 'python setup.py --version',
-            "PackageInfo": 'python setup.py --version',
-            "debian": utils._parse_deb_version,
+        'PackageInfo': {
+            "sdist": 'python setup.py -q sdist -d $dist_dir',
+            "clean": 'python setup.py clean --all',
+            "version": 'python setup.py --version',
+            "project": 'python setup.py --name',
         },
-        "project" : {
-            "file": '$setup project',
-            "Distribution": 'python setup.py --name',
-            "PackageInfo": 'python setup.py --name',
-            "debian": utils._parse_deb_project,
+        'debian': {
+            "sdist": "uscan --noconf --download-current-version --destdir $dist_dir",
+            "clean": "fakeroot debian/rules clean",
+            "version": utils._parse_deb_version,
+            "project": utils._parse_deb_project,
         },
 }
 
@@ -170,7 +167,7 @@ class SetupInfo(clcommands.Command):
         else:
             # Redirect subprocesses stdout output only in case of verbose mode
             # We always allow subprocesses to print on the stderr (more convenient)
-            sys.stdout = open(os.devnull,"w")
+            sys.stdout = open(os.devnull, "w")
             #sys.stderr = open(os.devnull,"w")
         if self.config.quiet:
             loglevel = logging.ERROR if (self.config.quiet >= 2) else logging.WARN
@@ -178,7 +175,7 @@ class SetupInfo(clcommands.Command):
         if self.isatty and not getattr(self.config, "no_color", None):
             # FIXME when using logging.conf
             handlers = logging.getLogger().handlers
-            assert len(handlers)==1, "Lgp cannot manage several handlers..."
+            assert len(handlers) == 1, "Lgp cannot manage several handlers..."
             console = logging.getLogger().handlers[0]
             console.setFormatter(ColorFormatter(LOG_FORMAT))
 
@@ -231,10 +228,10 @@ class SetupInfo(clcommands.Command):
     def _set_package_format(self):
         """set the package format to be able to run COMMANDS
 
-        setup_file must not be redefine since we can call this
+        setup_file must not be redefined since we can call this
         method several times
         """
-        setup_file = self.config.setup_file = self._normpath(self.config.setup_file)
+        setup_file = self._normpath(self.config.setup_file)
         if setup_file:
             self.logger.info('use specific setup file: %s', setup_file)
 
@@ -249,7 +246,8 @@ class SetupInfo(clcommands.Command):
         elif osp.isfile(setup_file):
             if osp.basename(setup_file) == 'setup.py':
                 # case for python project (distutils, setuptools)
-                self.config._package = run_setup(setup_file, None, stop_after="init")
+                self.config._package = run_setup(setup_file, None,
+                                                 stop_after="init")
             else:
                 # generic case: the setup file should only honor targets as:
                 # sdist, project, version, clean (see COMMANDS)
@@ -258,8 +256,12 @@ class SetupInfo(clcommands.Command):
                     raise LGPException('setup file %s has no execute permission'
                                        % setup_file)
         else:
-            class debian(object): pass
-            self.config._package = debian()
+            if self.config.rpm:
+                class rpm(object): pass
+                self.config._package = rpm()
+            else:
+                class debian(object): pass
+                self.config._package = debian()
         self.logger.debug("use setup package class format: %s" % self.package_format)
 
     def _prune_pkg_dir(self):
@@ -283,7 +285,7 @@ class SetupInfo(clcommands.Command):
         if isinstance(cmd, list):
             cmdline = ' '.join(cmd)
         else:
-            cmd = COMMANDS[cmd][self.package_format]
+            cmd = COMMANDS[self.package_format][cmd]
             if callable(cmd):
                 try:
                     return cmd()
@@ -383,107 +385,13 @@ class SetupInfo(clcommands.Command):
             msg %= (upstream_version, debian_upstream_version)
             raise LGPException(msg)
 
-    def prepare_source_archive(self, tmpdir, current_distrib):
-        """prepare and extract the upstream tarball
-
-        FIXME replace by TarFile Object
-        """
-        # Mandatory to be compatible with format 1.0
-        self.logger.debug("copy pristine tarball to prepare Debian source package diff")
-        cp(self.config.orig_tarball, tmpdir)
-        # TODO obtain current format version
-        # os.path.exists(osp.join(self.origpath, "debian/source/format")
-
-        self.logger.debug("extracting original source archive for %s distribution in %s"
-                          % (current_distrib or "default", tmpdir))
-        try:
-            cmd = 'tar --atime-preserve --preserve-permissions --preserve-order -xzf %s -C %s'\
-                  % (self.config.orig_tarball, tmpdir)
-            check_call(cmd.split(), stdout=sys.stdout)
-        except CalledProcessError, err:
-            raise LGPCommandException('an error occured while extracting the '
-                                      'upstream tarball', err)
-
-        # Find the right orig path in tarball
-        # It can be different of the standard <upstream-name>-<upstream-version>
-        # if pristine tarball was retrieve remotely (vcs frontend for example)
-        self.origpath = [d for d in os.listdir(tmpdir)
-                         if osp.isdir(osp.join(tmpdir,d))][0]
-
-        format = "%s-%s" % (self.get_upstream_name(), self.get_upstream_version())
-        if self.origpath != format:
-            self.logger.warn("source directory of original source archive (pristine tarball) "
-                             "has not the expected format (%s): %s" % (format, self.origpath))
-
-        # directory containing the debianized source tree
-        # (i.e. with a debian sub-directory and maybe changes to the original files)
-        # origpath is depending of the upstream convention
-        self.origpath = osp.join(tmpdir, self.origpath)
-
-        # support of the multi-distribution
-        return self.manage_current_distribution(current_distrib)
-
-    def manage_current_distribution(self, distrib):
-        """manage debian files depending of the current distrib from options
-
-        We copy debian_dir directory into tmp build depending of the target distribution
-        in all cases, we copy the debian directory of the default version (unstable)
-        If a file should not be included, touch an empty file in the overlay
-        directory.
-
-        This is specific to Logilab (debian directory is in project directory)
-        """
-        try:
-            # don't forget the final slash!
-            export(osp.join(self.config.pkg_dir, 'debian'), osp.join(self.origpath, 'debian/'),
-                   verbose=self.config.verbose == 2)
-        except IOError, err:
-            raise LGPException(err)
-
-        debian_dir = self.get_debian_dir(distrib)
-        if debian_dir != "debian":
-            self.logger.info("overriding files from '%s' directory..." % debian_dir)
-            # don't forget the final slash!
-            export(osp.join(self.config.pkg_dir, debian_dir), osp.join(self.origpath, 'debian/'),
-                   verbose=self.config.verbose)
-
-        from debian.changelog import Changelog
-        debchangelog = osp.join(self.origpath, 'debian', 'changelog')
-        changelog = Changelog(open(debchangelog))
-        # substitute distribution string in changelog
-        if distrib:
-            # squeeze python-debian doesn't handle unicode well, see Debian bug#561805
-            changelog.distributions = str(distrib)
-        # append suffix string (or timestamp if suffix is empty) to debian revision
-        if self.config.suffix is not None:
-            suffix = self.config.suffix or '+%s' % int(time.time())
-            self.logger.debug("suffix '%s' added to package version" % suffix)
-            changelog.version = str(changelog.version) + suffix
-        changelog.write_to_open_file(open(debchangelog, 'w'))
-
-        return self.origpath
-
     def get_basetgz(self, distrib, arch, check=True):
         basetgz = osp.join(self.config.basetgz, "%s-%s.tgz" % (distrib, arch))
         if check and not osp.exists(basetgz):
-            raise LGPException("lgp image '%s' not found. Please create it with lgp setup" % basetgz)
+            msg = "lgp image '%s' not found. Please create it with lgp setup"
+            raise LGPException(msg % basetgz)
         return basetgz
 
-    def create_tmp_context(self, suffix=""):
-        """create new build temporary context
-
-        Each context (directory for now) will be cleaned at the end of the build
-        process by the destroy_tmp_context method"""
-        self._tmpdir = tempfile.mkdtemp(suffix)
-        self.logger.debug('changing build context... (%s)' % self._tmpdir )
-        self._tmpdirs.append(self._tmpdir)
-        return self._tmpdir
-
-    def destroy_tmp_context(self):
-        """clean all temporary build context and returns exit code"""
-        self.clean_tmpdirs()
-        return self.build_status
-
     def _normpath(self, path):
         """helper method to normalize filepath arguments before
         changing current directory (will return absolute paths)
@@ -501,9 +409,9 @@ class SetupInfo(clcommands.Command):
 
     def get_distrib_dir(self, distrib):
         """get the dynamic target release directory"""
-        distrib_dir = os.path.normpath(os.path.expanduser(self.config.dist_dir))
+        distrib_dir = self._normpath(self.config.dist_dir)
         # special case when current directory is used to put result files ("-r .")
-        if distrib_dir not in ['.', '..']:
+        if self.config.dist_dir not in ['.', '..']:
             distrib_dir = os.path.join(distrib_dir, distrib)
         # check if distribution directory exists, create it if necessary
         os.umask(0002)
